@@ -6,11 +6,13 @@ S_gdk_bitmap_class_init(GdkDrawableClass * c, SEXP e)
   SEXP s;
 
   S_GdkBitmap_symbol = install("GdkBitmap");
-  s = findVar(S_GdkBitmap_symbol, e);
+  s = PROTECT(findVar(S_GdkBitmap_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkDrawableClass)) = e;
 
   S_gdk_drawable_class_init(((GdkDrawableClass *)c), e);
 
+  UNPROTECT(1);
+
 } 
 
 static SEXP S_GdkColormap_symbol;
@@ -20,11 +22,13 @@ S_gdk_colormap_class_init(GdkColormapClass * c, SEXP e)
   SEXP s;
 
   S_GdkColormap_symbol = install("GdkColormap");
-  s = findVar(S_GdkColormap_symbol, e);
+  s = PROTECT(findVar(S_GdkColormap_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkColormapClass)) = e;
 
   S_gobject_class_init(((GObjectClass *)c), e);
 
+  UNPROTECT(1);
+
 } 
 
 static SEXP S_GdkDisplay_symbol;
@@ -167,11 +171,13 @@ S_gdk_display_class_init(GdkDisplayClass * c, SEXP e)
   SEXP s;
 
   S_GdkDisplay_symbol = install("GdkDisplay");
-  s = findVar(S_GdkDisplay_symbol, e);
+  s = PROTECT(findVar(S_GdkDisplay_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkDisplayClass)) = e;
 
   S_gobject_class_init(((GObjectClass *)c), e);
 
+  UNPROTECT(1);
+
   if(VECTOR_ELT(s, 0) != NULL_USER_OBJECT)
     c->get_display_name = S_virtual_gdk_display_get_display_name;
   if(VECTOR_ELT(s, 1) != NULL_USER_OBJECT)
@@ -298,11 +304,13 @@ S_gdk_display_manager_class_init(GdkDisplayManagerClass * c, SEXP e)
   SEXP s;
 
   S_GdkDisplayManager_symbol = install("GdkDisplayManager");
-  s = findVar(S_GdkDisplayManager_symbol, e);
+  s = PROTECT(findVar(S_GdkDisplayManager_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkDisplayManagerClass)) = e;
 
   S_gobject_class_init(((GObjectClass *)c), e);
 
+  UNPROTECT(1);
+
   if(VECTOR_ELT(s, 0) != NULL_USER_OBJECT)
     c->display_opened = S_virtual_gdk_display_manager_display_opened;
 }
@@ -329,11 +337,13 @@ S_gdk_drag_context_class_init(GdkDragContextClass * c, SEXP e)
   SEXP s;
 
   S_GdkDragContext_symbol = install("GdkDragContext");
-  s = findVar(S_GdkDragContext_symbol, e);
+  s = PROTECT(findVar(S_GdkDragContext_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkDragContextClass)) = e;
 
   S_gobject_class_init(((GObjectClass *)c), e);
 
+  UNPROTECT(1);
+
 } 
 
 static SEXP S_GdkDrawable_symbol;
@@ -1189,11 +1199,13 @@ S_gdk_drawable_class_init(GdkDrawableClass * c, SEXP e)
   SEXP s;
 
   S_GdkDrawable_symbol = install("GdkDrawable");
-  s = findVar(S_GdkDrawable_symbol, e);
+  s = PROTECT(findVar(S_GdkDrawable_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkDrawableClass)) = e;
 
   S_gobject_class_init(((GObjectClass *)c), e);
 
+  UNPROTECT(1);
+
   if(VECTOR_ELT(s, 0) != NULL_USER_OBJECT)
     c->create_gc = S_virtual_gdk_drawable_create_gc;
   if(VECTOR_ELT(s, 1) != NULL_USER_OBJECT)
@@ -1490,7 +1502,8 @@ S_gdk_drawable_class_get_size(USER_OBJECT_ s_object_class, USER_OBJECT_ s_object
   object_class->get_size(object, &width, &height);
 
 
-  _result = retByVal(_result, "width", asRInteger(width), "height", asRInteger(height), NULL);
+  _result = retByVal(PROTECT(_result), "width", PROTECT(asRInteger(width)), "height", PROTECT(asRInteger(height)), NULL);
+  UNPROTECT(3);
   ;
   ;
 
@@ -1631,7 +1644,8 @@ S_gdk_drawable_class_get_composite_drawable(USER_OBJECT_ s_object_class, USER_OB
 
   _result = toRPointerWithFinalizer(ans, "GdkDrawable", (RPointerFinalizer) g_object_unref);
 
-  _result = retByVal(_result, "composite.x.offset", asRInteger(composite_x_offset), "composite.y.offset", asRInteger(composite_y_offset), NULL);
+  _result = retByVal(PROTECT(_result), "composite.x.offset", PROTECT(asRInteger(composite_x_offset)), "composite.y.offset", PROTECT(asRInteger(composite_y_offset)), NULL);
+  UNPROTECT(3);
   ;
   ;
 
@@ -1724,11 +1738,13 @@ S_gdk_window_class_init(GdkWindowClass * c, SEXP e)
   SEXP s;
 
   S_GdkWindow_symbol = install("GdkWindow");
-  s = findVar(S_GdkWindow_symbol, e);
+  s = PROTECT(findVar(S_GdkWindow_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkWindowClass)) = e;
 
   S_gdk_drawable_class_init(((GdkDrawableClass *)c), e);
 
+  UNPROTECT(1);
+
 } 
 
 static SEXP S_GdkPixmap_symbol;
@@ -1738,11 +1754,13 @@ S_gdk_pixmap_class_init(GdkPixmapObjectClass * c, SEXP e)
   SEXP s;
 
   S_GdkPixmap_symbol = install("GdkPixmap");
-  s = findVar(S_GdkPixmap_symbol, e);
+  s = PROTECT(findVar(S_GdkPixmap_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkPixmapObjectClass)) = e;
 
   S_gdk_drawable_class_init(((GdkDrawableClass *)c), e);
 
+  UNPROTECT(1);
+
 } 
 
 static SEXP S_GdkGC_symbol;
@@ -1842,11 +1860,13 @@ S_gdk_gc_class_init(GdkGCClass * c, SEXP e)
   SEXP s;
 
   S_GdkGC_symbol = install("GdkGC");
-  s = findVar(S_GdkGC_symbol, e);
+  s = PROTECT(findVar(S_GdkGC_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkGCClass)) = e;
 
   S_gobject_class_init(((GObjectClass *)c), e);
 
+  UNPROTECT(1);
+
   if(VECTOR_ELT(s, 0) != NULL_USER_OBJECT)
     c->get_values = S_virtual_gdk_gc_get_values;
   if(VECTOR_ELT(s, 1) != NULL_USER_OBJECT)
@@ -1866,7 +1886,8 @@ S_gdk_gcclass_get_values(USER_OBJECT_ s_object_class, USER_OBJECT_ s_object)
   object_class->get_values(object, values);
 
 
-  _result = retByVal(_result, "values", asRGdkGCValues(values), NULL);
+  _result = retByVal(PROTECT(_result), "values", PROTECT(asRGdkGCValues(values)), NULL);
+  UNPROTECT(2);
     CLEANUP(g_free, values);;
 
   return(_result);
@@ -1897,11 +1918,13 @@ S_gdk_image_class_init(GdkImageClass * c, SEXP e)
   SEXP s;
 
   S_GdkImage_symbol = install("GdkImage");
-  s = findVar(S_GdkImage_symbol, e);
+  s = PROTECT(findVar(S_GdkImage_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkImageClass)) = e;
 
   S_gobject_class_init(((GObjectClass *)c), e);
 
+  UNPROTECT(1);
+
 } 
 
 static SEXP S_GdkKeymap_symbol;
@@ -1961,11 +1984,13 @@ S_gdk_keymap_class_init(GdkKeymapClass * c, SEXP e)
   SEXP s;
 
   S_GdkKeymap_symbol = install("GdkKeymap");
-  s = findVar(S_GdkKeymap_symbol, e);
+  s = PROTECT(findVar(S_GdkKeymap_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkKeymapClass)) = e;
 
   S_gobject_class_init(((GObjectClass *)c), e);
 
+  UNPROTECT(1);
+
   if(VECTOR_ELT(s, 0) != NULL_USER_OBJECT)
     c->direction_changed = S_virtual_gdk_keymap_direction_changed;
   if(VECTOR_ELT(s, 1) != NULL_USER_OBJECT)
@@ -2114,11 +2139,13 @@ S_gdk_pixbuf_animation_class_init(GdkPixbufAnimationClass * c, SEXP e)
   SEXP s;
 
   S_GdkPixbufAnimation_symbol = install("GdkPixbufAnimation");
-  s = findVar(S_GdkPixbufAnimation_symbol, e);
+  s = PROTECT(findVar(S_GdkPixbufAnimation_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkPixbufAnimationClass)) = e;
 
   S_gobject_class_init(((GObjectClass *)c), e);
 
+  UNPROTECT(1);
+
   if(VECTOR_ELT(s, 0) != NULL_USER_OBJECT)
     c->is_static_image = S_virtual_gdk_pixbuf_animation_is_static_image;
   if(VECTOR_ELT(s, 1) != NULL_USER_OBJECT)
@@ -2173,7 +2200,8 @@ S_gdk_pixbuf_animation_class_get_size(USER_OBJECT_ s_object_class, USER_OBJECT_
   object_class->get_size(object, &width, &height);
 
 
-  _result = retByVal(_result, "width", asRInteger(width), "height", asRInteger(height), NULL);
+  _result = retByVal(PROTECT(_result), "width", PROTECT(asRInteger(width)), "height", PROTECT(asRInteger(height)), NULL);
+  UNPROTECT(3);
   ;
   ;
 
@@ -2311,11 +2339,13 @@ S_gdk_pixbuf_animation_iter_class_init(GdkPixbufAnimationIterClass * c, SEXP e)
   SEXP s;
 
   S_GdkPixbufAnimationIter_symbol = install("GdkPixbufAnimationIter");
-  s = findVar(S_GdkPixbufAnimationIter_symbol, e);
+  s = PROTECT(findVar(S_GdkPixbufAnimationIter_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkPixbufAnimationIterClass)) = e;
 
   S_gobject_class_init(((GObjectClass *)c), e);
 
+  UNPROTECT(1);
+
   if(VECTOR_ELT(s, 0) != NULL_USER_OBJECT)
     c->get_delay_time = S_virtual_gdk_pixbuf_animation_iter_get_delay_time;
   if(VECTOR_ELT(s, 1) != NULL_USER_OBJECT)
@@ -2510,11 +2540,13 @@ S_gdk_pixbuf_loader_class_init(GdkPixbufLoaderClass * c, SEXP e)
   SEXP s;
 
   S_GdkPixbufLoader_symbol = install("GdkPixbufLoader");
-  s = findVar(S_GdkPixbufLoader_symbol, e);
+  s = PROTECT(findVar(S_GdkPixbufLoader_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkPixbufLoaderClass)) = e;
 
   S_gobject_class_init(((GObjectClass *)c), e);
 
+  UNPROTECT(1);
+
   if(VECTOR_ELT(s, 0) != NULL_USER_OBJECT)
     c->size_prepared = S_virtual_gdk_pixbuf_loader_size_prepared;
   if(VECTOR_ELT(s, 1) != NULL_USER_OBJECT)
@@ -2594,11 +2626,13 @@ S_gdk_pango_renderer_class_init(GdkPangoRendererClass * c, SEXP e)
   SEXP s;
 
   S_GdkPangoRenderer_symbol = install("GdkPangoRenderer");
-  s = findVar(S_GdkPangoRenderer_symbol, e);
+  s = PROTECT(findVar(S_GdkPangoRenderer_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkPangoRendererClass)) = e;
 
   S_pango_renderer_class_init(((PangoRendererClass *)c), e);
 
+  UNPROTECT(1);
+
 } 
 
 static SEXP S_GdkScreen_symbol;
@@ -2627,7 +2661,6 @@ S_virtual_gdk_screen_size_changed(GdkScreen* s_object)
   if(err)
     return;
 }
-#if GDK_CHECK_VERSION(2, 10, 0)
 
 static void
 S_virtual_gdk_screen_composited_changed(GdkScreen* s_object)
@@ -2653,18 +2686,19 @@ S_virtual_gdk_screen_composited_changed(GdkScreen* s_object)
   if(err)
     return;
 }
-#endif
 void
 S_gdk_screen_class_init(GdkScreenClass * c, SEXP e)
 {
   SEXP s;
 
   S_GdkScreen_symbol = install("GdkScreen");
-  s = findVar(S_GdkScreen_symbol, e);
+  s = PROTECT(findVar(S_GdkScreen_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkScreenClass)) = e;
 
   S_gobject_class_init(((GObjectClass *)c), e);
 
+  UNPROTECT(1);
+
   if(VECTOR_ELT(s, 0) != NULL_USER_OBJECT)
     c->size_changed = S_virtual_gdk_screen_size_changed;
 #if GDK_CHECK_VERSION(2, 10, 0)
@@ -2713,11 +2747,13 @@ S_gdk_app_launch_context_class_init(GdkAppLaunchContextClass * c, SEXP e)
   SEXP s;
 
   S_GdkAppLaunchContext_symbol = install("GdkAppLaunchContext");
-  s = findVar(S_GdkAppLaunchContext_symbol, e);
+  s = PROTECT(findVar(S_GdkAppLaunchContext_symbol, e));
   G_STRUCT_MEMBER(SEXP, c, sizeof(GdkAppLaunchContextClass)) = e;
 
   S_gapp_launch_context_class_init(((GAppLaunchContextClass *)c), e);
 
+  UNPROTECT(1);
+
 }
 #endif 
 
