@@ -1,7 +1,4 @@
-#include "conversion.h"
-#include "gobject.h"
-#include "utils.h"
-#include "userfuncs.h"
+#include "RGtk2/gtk.h"
 
 gboolean
 S_GdkWindowInvalidateMaybeRecurseFunc(GdkWindow* s_window, gpointer s_data)
@@ -66,8 +63,9 @@ USER_OBJECT_
          geometry = asCGdkGeometry(s_geometry, &flags);
           gdk_window_constrain_size ( geometry, flags, width, height, &new_width, &new_height );
 
-        _result = retByVal(_result, "new_width", asRInteger ( new_width ), "new_height", asRInteger ( new_height ), NULL);
+	  _result = retByVal(_result, "new.width", PROTECT(asRInteger(new_width)), "new.height", PROTECT(asRInteger(new_height)), NULL);
 
+	  UNPROTECT(2);
         return(_result);
 }
 
@@ -81,7 +79,7 @@ USER_OBJECT_
          GdkGC* ans ;
         USER_OBJECT_ _result = NULL_USER_OBJECT;
 
-        values = asCGdkGCValues(s_values, &values_mask);
+        values = asCGdkGCValuesWithMask(s_values, &values_mask);
 
          ans =  gdk_gc_new_with_values ( object, values, values_mask );
         _result = toRPointerWithRef ( ans, "GdkGC" );
@@ -97,13 +95,47 @@ USER_OBJECT_
          GdkGCValuesMask values_mask;
         USER_OBJECT_ _result = NULL_USER_OBJECT;
 
-        values = asCGdkGCValues(s_values, &values_mask) ;
+        values = asCGdkGCValuesWithMask(s_values, &values_mask) ;
 
           gdk_gc_set_values ( object, values, values_mask );
 
         return(_result);
 }
 
+USER_OBJECT_
+S_gdk_drawable_class_create_gc(USER_OBJECT_ s_object_class, USER_OBJECT_ s_object, USER_OBJECT_ s_values)
+{
+  GdkDrawableClass* object_class = ((GdkDrawableClass*)getPtrValue(s_object_class));
+  GdkDrawable* object = GDK_DRAWABLE(getPtrValue(s_object));
+  GdkGCValuesMask mask;
+  GdkGCValues* values = asCGdkGCValuesWithMask(s_values, &mask);
+  
+  GdkGC* ans;
+  USER_OBJECT_ _result = NULL_USER_OBJECT;
+
+  ans = object_class->create_gc(object, values, mask);
+
+  _result = toRPointerWithFinalizer(ans, "GdkGC", (RPointerFinalizer) g_object_unref);
+
+  return(_result);
+}
+USER_OBJECT_
+S_gdk_gcclass_set_values(USER_OBJECT_ s_object_class, USER_OBJECT_ s_object, USER_OBJECT_ s_values)
+{
+  GdkGCClass* object_class = ((GdkGCClass*)getPtrValue(s_object_class));
+  GdkGC* object = GDK_GC(getPtrValue(s_object));
+  GdkGCValuesMask mask;
+  GdkGCValues* values = asCGdkGCValuesWithMask(s_values, &mask);
+  
+  USER_OBJECT_ _result = NULL_USER_OBJECT;
+
+  object_class->set_values(object, values, mask);
+
+
+  return(_result);
+}
+
+
 void
 S_GdkPixbufDestroyNotify(guchar *pixels, gpointer data)
 {
@@ -114,7 +146,7 @@ S_GdkPixbufDestroyNotify(guchar *pixels, gpointer data)
 USER_OBJECT_
  S_gdk_pixbuf_new_from_data ( USER_OBJECT_ s_data, USER_OBJECT_ s_colorspace, USER_OBJECT_ s_has_alpha, USER_OBJECT_ s_bits_per_sample, USER_OBJECT_ s_width, USER_OBJECT_ s_height, USER_OBJECT_ s_rowstride )
 {
-         const guchar* data = (guchar *)CHAR_DEREF(STRING_ELT(s_data, 0)) ;
+         const guchar* data = RAW(s_data);
          GdkColorspace colorspace = (GdkColorspace)INTEGER_DATA(s_colorspace)[0] ;
          gboolean has_alpha = LOGICAL_DATA(s_has_alpha)[0] ;
          int bits_per_sample = INTEGER_DATA(s_bits_per_sample)[0] ;
@@ -156,9 +188,9 @@ USER_OBJECT_
         }
         gdk_device_free_history(events, n_events);
 
-        _result = retByVal(_result, "events", s_events, "n_events", asRInteger ( n_events ), NULL);
+        _result = retByVal(_result, "events", s_events, "n.events", PROTECT(asRInteger(n_events)), NULL);
 
-        UNPROTECT(1);
+        UNPROTECT(2);
         return(_result);
 }
 
@@ -254,12 +286,13 @@ S_gdk_window_new(USER_OBJECT_ s_parent, USER_OBJECT_ s_attributes)
         return(_result);
 }
 
-/* reason: just send NULL asC the dest and use returned value */
+/* reason: if dest is provided, we need to ref it on the way back, since we don't own it */
 USER_OBJECT_
-S_gdk_pixbuf_get_from_drawable(USER_OBJECT_ s_src, USER_OBJECT_ s_cmap, USER_OBJECT_ s_src_x, USER_OBJECT_ s_src_y, USER_OBJECT_ s_dest_x, USER_OBJECT_ s_dest_y, USER_OBJECT_ s_width, USER_OBJECT_ s_height)
+S_gdk_pixbuf_get_from_drawable(USER_OBJECT_ s_dest, USER_OBJECT_ s_src, USER_OBJECT_ s_cmap, USER_OBJECT_ s_src_x, USER_OBJECT_ s_src_y, USER_OBJECT_ s_dest_x, USER_OBJECT_ s_dest_y, USER_OBJECT_ s_width, USER_OBJECT_ s_height)
 {
+        GdkPixbuf* dest = s_dest == NULL_USER_OBJECT ? NULL : GDK_PIXBUF(getPtrValue(s_dest));
         GdkDrawable* src = GDK_DRAWABLE(getPtrValue(s_src));
-        GdkColormap* cmap = GDK_COLORMAP(getPtrValue(s_cmap));
+        GdkColormap* cmap = s_cmap == NULL_USER_OBJECT ? NULL : GDK_COLORMAP(getPtrValue(s_cmap));
         int src_x = (int)asCInteger(s_src_x);
         int src_y = (int)asCInteger(s_src_y);
         int dest_x = (int)asCInteger(s_dest_x);
@@ -269,11 +302,12 @@ S_gdk_pixbuf_get_from_drawable(USER_OBJECT_ s_src, USER_OBJECT_ s_cmap, USER_OBJ
 
         GdkPixbuf* ans;
         USER_OBJECT_ _result = NULL_USER_OBJECT;
-        GdkPixbuf* dest = NULL;
 
         ans = gdk_pixbuf_get_from_drawable(dest, src, cmap, src_x, src_y, dest_x, dest_y, width, height);
-
-        _result = toRPointerWithFinalizer(ans, "GdkPixbuf", (RPointerFinalizer)g_object_unref);
+        
+        if (!dest)
+          _result = toRPointerWithFinalizer(ans, "GdkPixbuf", (RPointerFinalizer)g_object_unref);
+        else _result = toRPointerWithRef(ans, "GdkPixbuf");
 
         return(_result);
 }
@@ -314,8 +348,9 @@ S_gdk_query_depths()
         gdk_query_depths(&depths, &count);
 
 
-        _result = retByVal(_result, "depths", asRIntegerArrayWithSize(depths, count), "count", asRInteger(count), NULL);
+        _result = retByVal(_result, "depths", PROTECT(asRIntegerArrayWithSize(depths, count)), "count", PROTECT(asRInteger(count)), NULL);
 
+	UNPROTECT(2);
         return(_result);
 }
 
@@ -331,8 +366,9 @@ S_gdk_query_visual_types()
         gdk_query_visual_types(&visual_types, &count);
 
 
-        _result = retByVal(_result, "visual_types", asREnumArrayWithSize(visual_types, GDK_TYPE_VISUAL_TYPE, count), "count", asRInteger(count), NULL);
+        _result = retByVal(_result, "visual.types", PROTECT(asREnumArrayWithSize(visual_types, GDK_TYPE_VISUAL_TYPE, count)), "count", PROTECT(asRInteger(count)), NULL);
 
+	UNPROTECT(2);
         return(_result);
 }
 
@@ -350,8 +386,9 @@ S_gdk_pixbuf_render_pixmap_and_mask(USER_OBJECT_ s_object, USER_OBJECT_ s_alpha_
         gdk_pixbuf_render_pixmap_and_mask(object, &pixmap_return, &mask_return, alpha_threshold);
 
 
-        _result = retByVal(_result, "pixmap_return", toRPointerWithFinalizer(pixmap_return, "GdkPixmap", (RPointerFinalizer)g_object_unref), "mask_return", toRPointerWithFinalizer(mask_return, "GdkBitmap", (RPointerFinalizer) g_object_unref), NULL);
+        _result = retByVal(_result, "pixmap.return", PROTECT(toRPointerWithFinalizer(pixmap_return, "GdkPixmap", (RPointerFinalizer)g_object_unref)), "mask.return", PROTECT(toRPointerWithFinalizer(mask_return, "GdkBitmap", (RPointerFinalizer) g_object_unref)), NULL);
 
+	UNPROTECT(2);
         return(_result);
 }
 USER_OBJECT_
@@ -368,8 +405,9 @@ S_gdk_pixbuf_render_pixmap_and_mask_for_colormap(USER_OBJECT_ s_object, USER_OBJ
         gdk_pixbuf_render_pixmap_and_mask_for_colormap(object, colormap, &pixmap_return, &mask_return, alpha_threshold);
 
 
-        _result = retByVal(_result, "pixmap_return", toRPointerWithFinalizer(pixmap_return, "GdkPixmap", (RPointerFinalizer)g_object_unref), "mask_return", toRPointerWithFinalizer(mask_return, "GdkBitmap", (RPointerFinalizer)g_object_unref), NULL);
+        _result = retByVal(_result, "pixmap.return", PROTECT(toRPointerWithFinalizer(pixmap_return, "GdkPixmap", (RPointerFinalizer)g_object_unref)), "mask.return", PROTECT(toRPointerWithFinalizer(mask_return, "GdkBitmap", (RPointerFinalizer)g_object_unref)), NULL);
 
+	UNPROTECT(2);
         return(_result);
 }
 /* reason: when a color is allocated, the pixel field is set, so we must return the color as part of a list */
@@ -386,8 +424,10 @@ S_gdk_colormap_alloc_color(USER_OBJECT_ s_object, USER_OBJECT_ s_color, USER_OBJ
 
 	ans = gdk_colormap_alloc_color(object, color, writeable, best_match);
 
-	_result = retByVal(asRLogical(ans), "color", asRGdkColor(color));
+	_result = retByVal(PROTECT(asRLogical(ans)), "color",
+			   PROTECT(asRGdkColor(color)));
 
+	UNPROTECT(2);
 	return(_result);
 }
 /* reason: as above, the pixel field is set when found, must return it */
@@ -474,11 +514,11 @@ S_gdk_pixbuf_save_to_bufferv(USER_OBJECT_ s_object, USER_OBJECT_ s_type, USER_OB
 		for (i = 0; i < buffer_size; i++)
 			RAW(_result)[i] = (Rbyte)buffer[i];
 		
-        _result = retByVal(NULL_USER_OBJECT, "buffer", _result, "buffer_size", asRNumeric(buffer_size), "error", asRGError(error), NULL);
+		_result = retByVal(NULL_USER_OBJECT, "buffer", _result, "buffer.size", PROTECT(asRNumeric(buffer_size)), "error", PROTECT(asRGError(error)), NULL);
         CLEANUP(g_error_free, error);
 		CLEANUP(g_free, buffer);
 		
-		UNPROTECT(1);
+		UNPROTECT(3);
         return(_result);
 }
 /* reason: needed to get the GdkPixbuf error quark */
@@ -495,3 +535,4 @@ S_gdk_pixbuf_error_quark()
 
 	return(_result);
 }
+
